==> estateplat-common-1.2.4-20220607.092754-1035-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptDyqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_dyqk")
public class GxTcJcptDyqk {
    @Id
    private String ywid;
    private String bjbh;
    private Double bdbzqse;
    private Double bdcpgjg;
    private String dbfw;
    private Integer dyfs;
    private String dyhtbh;
    private String dysw;
    private String zqr;
    private String zwlxjssj;
    private String zwlxqssj;
    private String zwr;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public Double getBdbzqse() {
        return bdbzqse;
    }

    public void setBdbzqse(Double bdbzqse) {
        this.bdbzqse = bdbzqse;
    }

    public Double getBdcpgjg() {
        return bdcpgjg;
    }

    public void setBdcpgjg(Double bdcpgjg) {
        this.bdcpgjg = bdcpgjg;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public Integer getDyfs() {
        return dyfs;
    }

    public void setDyfs(Integer dyfs) {
        this.dyfs = dyfs;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDysw() {
        return dysw;
    }

    public void setDysw(String dysw) {
        this.dysw = dysw;
    }

    public String getZqr() {
        return zqr;
    }

    public void setZqr(String zqr) {
        this.zqr = zqr;
    }

    public String getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(String zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(String zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }
}

==> estateplat-common-1.2.4-20220611.095919-1037-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptDyqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_dyqk")
public class GxTcJcptDyqk {
    @Id
    private String ywid;
    private String bjbh;
    private Double bdbzqse;
    private Double bdcpgjg;
    private String dbfw;
    private Integer dyfs;
    private String dyhtbh;
    private String dysw;
    private String zqr;
    private String zwlxjssj;
    private String zwlxqssj;
    private String zwr;
    private String sfxzzr;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public Double getBdbzqse() {
        return bdbzqse;
    }

    public void setBdbzqse(Double bdbzqse) {
        this.bdbzqse = bdbzqse;
    }

    public Double getBdcpgjg() {
        return bdcpgjg;
    }

    public void setBdcpgjg(Double bdcpgjg) {
        this.bdcpgjg = bdcpgjg;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public Integer getDyfs() {
        return dyfs;
    }

    public void setDyfs(Integer dyfs) {
        this.dyfs = dyfs;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDysw() {
        return dysw;
    }

    public void setDysw(String dysw) {
        this.dysw = dysw;
    }

    public String getZqr() {
        return zqr;
    }

    public void setZqr(String zqr) {
        this.zqr = zqr;
    }

    public String getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(String zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(String zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getSfxzzr() {
        return sfxzzr;
    }

    public void setSfxzzr(String sfxzzr) {
        this.sfxzzr = sfxzzr;
    }
}
